======================
Liege.urban.dataimport
======================

liege urban dataimport

* `Source code @ GitHub <https://github.com/IMIO/Liege.urban.dataimport>`_
* `Releases @ PyPI <http://pypi.python.org/pypi/Liege.urban.dataimport>`_
* `Documentation @ ReadTheDocs <http://Liegeurbandataimport.readthedocs.org>`_
* `Continuous Integration @ Travis-CI <http://travis-ci.org/IMIO/Liege.urban.dataimport>`_

Installation
============

To install `Liege.urban.dataimport` you simply add ``Liege.urban.dataimport``
to the list of eggs in your buildout, run buildout and restart Plone.
Then, install `Liege.urban.dataimport` using the Add-ons control panel.

